import React, { useEffect } from "react";

import { PayPalProps } from "../";


export const Content = ({ onSubmit, braintreeAuthorization }: PayPalProps) => {
    useEffect(() => {
        //@ts-ignore
        window.braintree?.client.create({
            authorization: braintreeAuthorization,
        }, function (clientErr: any, clientInstance: any) {

            // Stop if there was a problem creating the client.
            // This could happen if there is a network error or if the authorization
            // is invalid.
            if (clientErr) {
                console.error('Error creating client:', clientErr);
                return;
            }

            // Create a PayPal Checkout component.
            //@ts-ignore
            window.braintree?.paypalCheckout.create({
                client: clientInstance,
            }, function (_:any, paypalCheckoutInstance: any) {
                paypalCheckoutInstance.loadPayPalSDK({
                    currency: 'USD',
                    intent: 'capture',
                    vault: true,
                }, function () {
                    //@ts-ignore
                    window.paypal?.Buttons({
                        style: {
                            layout:  'vertical',
                            height: 48,
                        },
                        //@ts-ignore
                        fundingSource: window.paypal.FUNDING.PAYPAL,

                        createBillingAgreement: function () {
                            return paypalCheckoutInstance.createPayment({
                                flow: 'vault', // Required
                                enableShippingAddress: true,
                            });
                        },

                        onApprove: function (data: any) {
                            return paypalCheckoutInstance.tokenizePayment(data, function (_: any, payload: any) {
                                console.log(data)
                                console.log(payload)
                                onSubmit(
                                    payload.nonce,
                                    payload.details,
                                    payload.details.shippingAddress
                                )
                            });
                        },

                        onCancel: function (data: any) {
                            //@ts-ignore
                            console.log('PayPal payment canceled', JSON.stringify(data, 0, 2));
                        },

                        onError: function (err: any) {
                            console.error('PayPal error', err);
                        }
                    }).render('#paypal-button').then(function () {
                        // The PayPal button will be rendered in an html element with the ID
                        // `paypal-button`. This function will be called when the PayPal button
                        // is set up and ready to be used
                    });

                });

            });

        });
    }, []);

    return <div id="paypal-button" />
}